/*******************************************************************
*  Kuvaus: Apumakroja tulostaulujen kokoamiseen, vertailuun ja 	   *
*		   tarkastamiseen.            							   * 
*  Viimeksi pivitetty: 24.1.2018 					               * 
*******************************************************************/

/* SISLLYS
0. Kyttohje
1. RenameNum
2. LaskeMuutos
3. Korosta
4. LaskeErotus - Pmakro, tulostaulujen vertailu
5. Vertaile - Pmakro, aineistojen tarkastus ja vertailu
6. LaskeSimple

################################################################### */

/* ##### 0. Kyttohje #####


Seuraavissa tiedostoissa on kyttliittym tulostiedostojen ja aineistojen vertailuun:

	Taulukointi.sas				Summataulujen vertailu
	TaulukointiAineisto.sas		Aineistojen vertailu

Makrot ja kytttarkoitus:

### LaskeErotus
Makroa kytetn summataulujen yhdistmiseen:

%LaskeErotus(tulos, inputTaulu1, inputTaulu2, tunnusluvut, suff1, suff2)

### Vertaile
Makroa kytetn aineistojen tarkastamiseen ja aineistojen vertailemiseen:

%Vertaile(inputTaulu1, inputTaulu2, paino1 = ykor, paino2 = ykor,
	tunnusluvut = sum, luokat = , muuttujat = _NUMERIC_, suff1 = _1, suff2 = _2, tulos = varkastus);

# Kyttohje 1: %LaskeErotus -makro

	%LaskeErotus(tulos, inputTaulu1, inputTaulu2, tunnusluvut, suff1, suff2)

	 tulos - tulostaulun osoite ja nimi
	 inputTaulu1 ja inputTaulu2 - saman kokoisia samoilla tunnusluvuilla laskettuja
		SISU-mallin tai muun taulun summatauluja
	 tunnusluvut - ne tunnusluvut mit lytyy summataulusta (esim sum, mean jne.)
	 suff1 - pte ensimmisen taulun muuttujille
	 suff2 - pte toisen taulun muuttujille

	Yll oleva esimerkki yhdist kolme taulua ja vertaa ensimmisen taulun sum-sarakkeeseen.

Lisksi alla olevalla koodilla voi laskea mist tahansa aineistosta summataulun painolla ykor:

	PROC MEANS DATA = OUTPUT.tulostaulu SUM STACKODS;
	var _ALL_; * tai _NUMERIC_;
	ODS OUTPUT SUMMARY = OUTPUT.tulostaulu_s;
	WEIGHT ykor;
	RUN;

# Kyttohje 2: %Vertaile -makro

Vertaile-makro summaa kaksi taulua, pakollisia parametreja ovat inputTaulu1 ja inputTaulu2,
jotka voivat olla mit tahansa yksikk- tai kotitaloustason tauluja.

	%Vertaile(inputTaulu1, inputTaulu2)

tai tarkastellessa vain tiettyj muuttujia

	%Vertaile(inputTaulu1, inputTaulu2, muuttujat = lista muuttujista);

*/

/* ################### Summataulujen yhdistminen ################### */

/* ##### 1. RenameNum #####

Makro joka lis data-askeleeseen yhden rivin RENAME-komentoja loopaten yli mlista-listan
ja listen alkuperisiin nimiin suff1-loppuptteen

Sisn:
	mlista
	suff1
*/

%MACRO RenameNum(mlista, suff1)/
DES = "VertailuMakrot: Apumakro muuttujien uudelleennimemiseksi annetulla ptteell";
	%LOCAL apu_muuttuja k;
	%LET k = 1;
	%LET apu_muuttuja = %SCAN(&mlista,&k);
	%DO %WHILE ("&apu_muuttuja" NE "");
		RENAME &apu_muuttuja = &apu_muuttuja.&suff1;
		LABEL  &apu_muuttuja = &apu_muuttuja.&suff1;
		%LET k = %EVAL(&k+1);
		%LET apu_muuttuja = %SCAN(&mlista,&k);
	%END;
%MEND RenameNum;

/* ##### 2. LaskeMuutos #####

Macro joka laskee kahden muuttujan erotuksen loopaten yli mlista-listan, joka on lista  vertailtavista
tunnusluvuista. Makro palauttaa tarkastaustykalua varten mys colorLista-makromuuttujan.

Sisn:
	mlista (tunnusluvut)
	suff1
	suff2

Uusien muuttujien nimiin yhdistetn suff1 ja suff2 pte ptteeksi suff1suff2 */

%MACRO LaskeMuutos(mlista, suff1, suff2)/
DES = "VertailuMakrot: Apumakro vertailtavien muuttujien erotuksen laskentaan";
	%LOCAL apu_muuttuja k;
	%LET k = 1;
	%LET apu_muuttuja = %SCAN(&mlista,&k);
	%DO %WHILE ("&apu_muuttuja" NE "");
		/* Laskutoimitukset */
		&apu_muuttuja._ero&suff1.&suff2 = &apu_muuttuja.&suff2 - &apu_muuttuja.&suff1;
		&apu_muuttuja._muutos&suff1.&suff2 = &apu_muuttuja._ero&suff1.&suff2 /  &apu_muuttuja.&suff1;
		LABEL &apu_muuttuja._ero&suff1.&suff2 = "Erotus &apu_muuttuja &suff2 - &suff1";
		LABEL &apu_muuttuja._muutos&suff1.&suff2 = "Muutospros &apu_muuttuja &suff2 - &suff1";

		%LET colorLista = &colorLista &apu_muuttuja._muutos&suff1.&suff2;

		%LET k = %EVAL(&k+1);
		%LET apu_muuttuja = %SCAN(&mlista,&k);
	%END;
%MEND LaskeMuutos;

/* ##### 3. Korosta #####

Makro, jolla listn vrikoodaus, jos vrikoodaus optio on pll. Toimii PROC REPORT sisll.


Sisn:
	lista
	raja1
	raja2

Listan muuttujien tytyy lyty ja olla uniikkeja. */

%MACRO Korosta(lista, raja1, raja2)/
DES = "VertailuMakrot: Apumakro vrikoodauksen lismiseksi vertailtaviin tauluihin";
  %LOCAL k haly_apu raja;
  %LET k=1;
  %LET haly_apu = %SCAN(&lista, &k);
     %DO %WHILE("&haly_apu" NE "");
	  DEFINE &haly_apu / DISPLAY;
	  COMPUTE &haly_apu;
		  IF abs(&haly_apu) >= &raja2 THEN CALL DEFINE(_col_,"style","style={background=yellow}");
		  IF abs(&haly_apu) >= &raja1 THEN CALL DEFINE(_col_,"style","style={background=red}");
	  ENDCOMP;
	  %LET k = %EVAL(&k + 1);
	  %LET haly_apu = %SCAN(&lista, &k);
  %END;
%MEND;

/* ##### 4. LaskeErotus #####

Makro luo work-hakemistoon tauluista kopiot, joihin tunnusluvut uudelleen nimetn loppuptteiden suff1 ja suff2 mukaan.
Makro yhdist byvar mukaan, esimerkiksi: byvar = desmod ikavu variable.
Makro laskee tunnuslukujen eron.
Makro vritt muutokset, jotka ylittvt ylemmn tai alemman rajan, jos tulostus ja vri -asetukset on valittu.

Sisn ja keyword variablejen oletusarvot:
	tulos
	inputTaulu1
	inputTaulu2
	tunnusluvut
	suff1
	suff2
	byvar = variable
	tulosta = 1
	color = 1
	yRaja=0.01
	aRaja = 0.00001 

Makro kytt makroja:
	%RenameNum
	%LaskeMuutos
	%Korosta
*/

%MACRO LaskeErotus(tulos, inputTaulu1, inputTaulu2, tunnusluvut, suff1, suff2, byvar = variable, tulosta = 1, color = 1, yRaja=0.01, aRaja = 0.00001)/
DES = "VertailuMakrot: Yhdistettvien taulujen muuttujien erotuksen laskenta";

/* Lista johon tallennetaan muuttujat vrikoodausta varten */
%LOCAL colorLista;
%LET colorLista=;

/* Uudelleen nimetn taulujen muuttuja loppuptteiden mukaan */
DATA apu1_yhd;
	SET &inputTaulu1;
	%IF %TRIM("&suff1") NE "" %THEN %DO;
	%RenameNum(&tunnusluvut, &suff1);
	%END;
RUN;

DATA apu2_yhd;
	SET &inputTaulu2;
	%RenameNum(&tunnusluvut, &suff2);
RUN;

/* Yhdistetn */
PROC SORT DATA = apu1_yhd; BY &byvar; RUN;
PROC SORT DATA = apu2_yhd; BY &byvar; RUN;

DATA yhd_temp;
	MERGE apu1_yhd apu2_yhd;
	BY &byvar;
RUN;

DATA &tulos;
	SET yhd_temp;
	%LaskeMuutos(&tunnusluvut, &suff1, &suff2);
RUN;

/* Valitaan muutokset vertailtaviksi ja vrikoodattaviksi */
%IF &tulosta EQ 1 and &color EQ 1 %THEN %DO;
	PROC CONTENTS DATA = &tulos (DROP = %VarExist(&byvar label)) OUT = nimet (keep=NAME) NOPRINT; RUN;

	PROC SQL NOPRINT;
		SELECT NAME INTO :color_lista separated by ' ' 
		FROM nimet
		WHERE NAME like '%muutos%';
	QUIT;
%END;

/* Proc report avulla color coding thn, jos optio = tosi
 HUOM! Jos columns _ALL_ -kohta tuottaa ongelmia (esim. tunnusluvun ollessa sum, mean, yms.)
SAS saattaa tulkita vrin: Tllin muuta PROC PRINT tai RENAME tai tulosta erikseen */
%IF &tulosta EQ 1 %THEN %DO;
	PROC REPORT DATA = &tulos;
	%IF &color = 1 %THEN %DO;
		%Korosta(&colorLista, &yRaja, &aRaja);
		FORMAT _NUMERIC_ tuhat.;
		FORMAT &color_lista percentn6.2;
	%END;
	RUN;
%END;


%MEND;

/* ##### 5. Vertaile #####

Makro, joka laskee summataulun kahdelle sisn sytetylle taululle samalla tavalla kuin KOKOtulokset-makrossa.

Sisn ja oletusarvot:
	inputTaulu1
	inputTaulu2
	paino1 = ykor
	paino2 = ykor
	tunnusluvut = sum
	luokat = 
	suff1 = _1
	suff2 = _2
	tulos = tarkastus

*/

%MACRO Vertaile(inputTaulu1, inputTaulu2, paino1 = ykor, paino2 = ykor, tunnusluvut = sum, luokat = , muuttujat = _NUMERIC_, suff1 = _1, suff2 = _2, tulos = tarkastus)/
DES = "VertailuMakrot: Yhdistetty summataulujen tuottaminen kahdesta taulusta ja tulosten yhdistminen";
	%LOCAL i;
	%LET i = 1;
	%DO %WHILE (&i < 3);
	PROC MEANS DATA = &&inputTaulu&i &tunnusluvut STACKODS;
		VAR &muuttujat;
		CLASS &luokat / MLF PRELOADFMT;
		/*FORMAT _NUMERIC_ tuhat. ;*/
		%DO k = 1 %TO 3; 
			%IF %LENGTH (%SCAN(&luokat, &k)) >0 %THEN %DO;
				FORMAT %SCAN(&luokat, &k) %SCAN(&luokat, &k). ;
			%END;
		%END;
		ODS OUTPUT SUMMARY = valitulos&i;
		WEIGHT &&paino&i;
	RUN;
	%LET i = %EVAL(&i + 1);
	%END;

	%LaskeErotus(&tulos, valitulos1, valitulos2, &tunnusluvut, &suff1, &suff2, byvar = &luokat variable, color = 1);
%MEND Vertaile;


/* ##### 6. LaskeSimple #####

Yksinkertainen taulukointi. Ei laske muuttujien erotusta.

Makro luo work-hakemistoon tauluista kopiot, joihin tunnusluvut uudelleen nimetn loppuptteiden suff1 ja suff2 mukaan.
Makro yhdist byvar mukaan, esimerkiksi: byvar = desmod ikavu variable.

Sisn ja keyword variablejen oletusarvot:
	tulos
	inputTaulu1
	inputTaulu2
	tunnusluvut
	suff1
	suff2
	byvar = variable

Makro kytt makroa:
	%RenameNum

*/
%MACRO LaskeSimple(tulos, inputTaulu1, inputTaulu2, tunnusluvut, suff1, suff2, byvar = variable)/
DES = "VertailuMakrot: Yksinkertainen tulostaulukoiden yhdistminen";

/* Uudelleen nimetn taulujen muuttuja loppuptteiden mukaan */
DATA apu1_yhd;
	SET &inputTaulu1;
	%IF %TRIM("&suff1") NE "" %THEN %DO;
	%RenameNum(&tunnusluvut, &suff1);
	%END;
RUN;

DATA apu2_yhd;
	SET &inputTaulu2;
	%RenameNum(&tunnusluvut, &suff2);
RUN;

/* Yhdistetn */
%IF "&byvar" NE "" %THEN %DO;
PROC SORT DATA = apu1_yhd; BY &byvar; RUN;
PROC SORT DATA = apu2_yhd; BY &byvar; RUN;
%END;

DATA &tulos;
	MERGE apu1_yhd apu2_yhd;
	%IF "&byvar" NE "" %THEN %DO;
		BY &byvar;
	%END;
RUN;

%MEND LaskeSimple;